@@ -16,7 +16,7 @@
 #  drives is a pain in the butt
 # 2-May-2002 - SGhosh fix for embedded perl
 #
-# $Id: check_disk_smb.pl,v 1.8 2003/02/20 03:16:26 kdebisschop Exp $
+# $Id: check_disk_smb.pl,v 1.8.2.1 2003/07/02 15:52:23 tonvoon Exp $
 #
 
 require 5.004;
@@ -51,7 +51,7 @@ GetOptions
 	 "H=s" => \$opt_H, "hostname=s" => \$opt_H);
 
 if ($opt_V) {
-	print_revision($PROGNAME,'$Revision: 1.8 $'); #'
+	print_revision($PROGNAME,'$Revision: 1.8.2.1 $'); #'
 	exit $ERRORS{'OK'};
 }
 
@@ -205,18 +205,17 @@ if (/\s*(\d*) blocks of size (\d*)\. (\d*) blocks available/) {
 	$answer = "Result from smbclient not suitable\n";
 	$state = "UNKNOWN";
 	foreach (@lines) {
-		if (/Access denied/) {
+		if (/(Access denied|NT_STATUS_LOGON_FAILURE)/) {
 			$answer = "Access Denied\n";
 			$state = "CRITICAL";
 			last;
 		}
-		if (/(Unknown host \w*)/) {
-			$answer = "$1\n";_
-
+		if (/(Unknown host \w*|Connection.*failed)/) {
+			$answer = "$1\n";
 			$state = "CRITICAL";
 			last;
 		}
-		if (/(You specified an invalid share name)/) {
+		if (/(You specified an invalid share name|NT_STATUS_BAD_NETWORK_NAME)/) {
 			$answer = "Invalid share name \\\\$host\\$share\n";
 			$state = "CRITICAL";
 			last;
@@ -235,7 +234,7 @@ sub print_usage () {
 }
 
 sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1.8 $');
+	print_revision($PROGNAME,'$Revision: 1.8.2.1 $');
 	print "Copyright (c) 2000 Michael Anthon/Karl DeBisschop
 
 Perl Check SMB Disk plugin for Nagios
