@@ -19,12 +19,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: check_http.c,v 1.24 2003/02/21 21:59:17 tonvoon Exp $
+ * $Id: check_http.c,v 1.24.2.4 2003/06/21 05:31:23 kdebisschop Exp $
  *
  *****************************************************************************/
 
 const char *progname = "check_http";
-#define REVISION "$Revision: 1.24 $"
+#define REVISION "$Revision: 1.24.2.4 $"
 #define COPYRIGHT "1999-2001"
 #define AUTHORS "Ethan Galstad/Karl DeBisschop"
 #define EMAIL "kdebisschop@users.sourceforge.net"
@@ -180,14 +180,14 @@ struct timeval tv;
 
 #define server_port_check(use_ssl) (use_ssl ? HTTPS_PORT : HTTP_PORT)
 
+/* per RFC 2396 */
 #define HDR_LOCATION "%*[Ll]%*[Oo]%*[Cc]%*[Aa]%*[Tt]%*[Ii]%*[Oo]%*[Nn]: "
 #define URI_HTTP "%[HTPShtps]://"
-#define URI_HOST "%[a-zA-Z0-9.-]"
-#define URI_PORT ":%[0-9]"
-#define URI_PATH "%[/a-zA-Z0-9._-=@,]"
-
+#define URI_HOST "%[-.abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789]"
+#define URI_PORT ":%[0123456789]"
+#define URI_PATH "%[-_.!~*'();/?:@&=+$,%#abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789]"
 enum {
-	MAX_IPV4_HOSTLENGTH = 64,
+	MAX_IPV4_HOSTLENGTH = 255,
 	HTTP_PORT = 80,
 	HTTPS_PORT = 443
 };
@@ -627,16 +627,21 @@ check_http (void)
 		pagesize += i;
 	}
 
-	if (i < 0) {
+	if (i < 0 && errno != ECONNRESET) {
+#ifdef HAVE_SSL
+		if (use_ssl) {
+			sslerr=SSL_get_error(ssl, i);
+			if ( sslerr == SSL_ERROR_SSL ) {
+				terminate (STATE_WARNING, "Client Certificate Required\n");
+			} else {
+				terminate (STATE_CRITICAL, "Error in recv()");
+			}
+		}
+		else {
+#endif
+			terminate (STATE_CRITICAL, "Error in recv()");
 #ifdef HAVE_SSL
-		sslerr=SSL_get_error(ssl, i);
-		if ( sslerr == SSL_ERROR_SSL ) {
-			terminate (STATE_WARNING, "Client Certificate Required\n");
-		} else {
-			terminate (STATE_CRITICAL, "Error in recv()");
 		}
-#else
-		terminate (STATE_CRITICAL, "Error in recv()");
 #endif
 	}
 
@@ -734,7 +739,7 @@ check_http (void)
 				asprintf (&orig_url, "%s", server_url);
 				pos = header;
 				while (pos) {
-					server_address = realloc (server_address, MAX_IPV4_HOSTLENGTH);
+					server_address = realloc (server_address, MAX_IPV4_HOSTLENGTH + 1);
 					if (server_address == NULL)
 						terminate (STATE_UNKNOWN,
 										 "HTTP UNKNOWN: could not allocate server_address");
