@@ -24,7 +24,7 @@
  *****************************************************************************/
 
 const char *progname = "check_snmp";
-#define REVISION "$Revision: 1.24 $"
+#define REVISION "$Revision: 1.24.2.2 $"
 #define COPYRIGHT "1999-2002"
 #define AUTHOR "Ethan Galstad"
 #define EMAIL "nagios@nagios.org"
@@ -167,7 +167,6 @@ char regex_expect[MAX_INPUT_BUFFER] = "";
 regex_t preg;
 regmatch_t pmatch[10];
 char timestamp[10] = "";
-char regex[MAX_INPUT_BUFFER];
 char errbuf[MAX_INPUT_BUFFER];
 int cflags = REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 int eflags = 0;
@@ -234,8 +233,9 @@ main (int argc, char **argv)
 		usage ("Incorrect arguments supplied\n");
 
 	/* create the command line to execute */
-	asprintf (&command_line, "%s -m %s -v %s %s %s:%s %s",
-	          PATH_TO_SNMPGET, miblist, proto, authpriv, server_address, port, oid);
+	asprintf (&command_line, "%s -t 1 -r %d -m %s -v %s %s %s:%s %s",
+	          PATH_TO_SNMPGET, timeout_interval - 1, miblist, proto,
+	          authpriv, server_address, port, oid);
 	if (verbose)
 		printf ("%s\n", command_line);
 
